slepc-3.18.0 2022-10-01
Report Typos and Errors

# EPSKrylovSchurGetDetectZeros

Gets the flag that enforces zero detection in spectrum slicing.

### Synopsis

    #include "slepceps.h"
    PetscErrorCode EPSKrylovSchurGetDetectZeros(EPS eps,PetscBool *detect)

Not Collective

### Input Parameter

| eps | - the eigenproblem solver context

### Output Parameter

| detect | - whether zeros detection is enforced during factorizations

### See Also

EPSKrylovSchurSetDetectZeros()

### Level

advanced

### Location

src/eps/impls/krylov/krylovschur/krylovschur.c
Index of all EPS routines
Table of Contents for all manual pages
Index of all manual pages